package com.ruoyi.system.mapper;

import java.util.List;
import com.ruoyi.system.domain.SysDeptfile;

/**
 * 部门文件Mapper接口
 * 
 * @author ruoyi
 * @date 2023-08-23
 */
public interface SysDeptfileMapper 
{
    /**
     * 查询部门文件
     * 
     * @param id 部门文件主键
     * @return 部门文件
     */
    public SysDeptfile selectSysDeptfileById(Long id);

    /**
     * 查询部门文件列表
     * 
     * @param sysDeptfile 部门文件
     * @return 部门文件集合
     */
    public List<SysDeptfile> selectSysDeptfileList(SysDeptfile sysDeptfile);

    /**
     * 新增部门文件
     * 
     * @param sysDeptfile 部门文件
     * @return 结果
     */
    public int insertSysDeptfile(SysDeptfile sysDeptfile);

    /**
     * 修改部门文件
     * 
     * @param sysDeptfile 部门文件
     * @return 结果
     */
    public int updateSysDeptfile(SysDeptfile sysDeptfile);

    /**
     * 删除部门文件
     * 
     * @param id 部门文件主键
     * @return 结果
     */
    public int deleteSysDeptfileById(Long id);

    /**
     * 批量删除部门文件
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteSysDeptfileByIds(Long[] ids);
}
